=========
slugifile
=========


.. image:: https://img.shields.io/pypi/v/slugifile.svg
        :target: https://pypi.python.org/pypi/slugifile

.. image:: https://img.shields.io/travis/codehutlabs/slugifile.svg
        :target: https://travis-ci.org/codehutlabs/slugifile

.. image:: https://readthedocs.org/projects/slugifile/badge/?version=latest
        :target: https://slugifile.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Renames the filenames within the specified directory to be Unix friendly.


* Free software: MIT license
* Documentation: https://slugifile.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `elgertam/cookiecutter-pipenv`_ project template, based on `audreyr/cookiecutter-pypackage`_.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`elgertam/cookiecutter-pipenv`: https://github.com/elgertam/cookiecutter-pipenv
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
